function [camPar, K] = camPar(Res)
% Function that creates an object camPar that contains the intrinsic 
% parameter of the camera.

% INPUT:
% Res: vector containing the camera resolution in the form: 
%      [vertical res, horizontal res].

% OUTPUT:
% K: intrinsic matrix.
% camPar: object containing the the camera parameters.

switch Res
    case 1 % NORMAL RESOLUTION [240 x 320]
        fx = 613.98; 
        fy = 613.03;
        x0 = 161.26; 
        y0 = 119.26;  
        alpha = 0;
        radialDist = [0 0 0]; 
        tanDist = [0 0]; 
    case 2 % SUPER RESOLUTION [480 x 640]
        fx = 1242.44;  
        fy = 1242.18;  
        x0 = 329.59;   
        y0 = 242.93;   
        alpha = 0;
        radialDist = [0 0 0]; 
        tanDist = [0 0]; 
    otherwise
        disp('No intrinsic parameters available');
end

K = [fx 0 0; alpha fy 0; x0 y0 1];

camPar = cameraParameters('IntrinsicMatrix',K ,'RadialDistortion',radialDist, 'TangentialDistortion', tanDist);
