function [vetTnew, vetSovrapNew, confNew] = combineVetT(vetT, conf, vetTtoAdd, conftoAdd, vetSovrap)
% Function that combines temperature vectors of different thermograms
% associated to the same point cloud.

% INPUT:
% vetT:         temperature vector previously associated with the point
%               cloud.
% conf:         confidence vector associated with vetT.
% vetTtoAdd:    temperature vector to combine with vetT.
% conftoAdd:    confidence vector associated with vetTtoAdd.
% vetSoprap:    vector containing the number of values of temperature
%               associated with each point (0 if no temperature, 1 if
%               1 temperature, etc.).
% OUTPUT:
% vetTnew:      vector resulting from the union of vetT and vetTtoAdd.
% vetSovrapNew: new vector containing the number of overlappings.
% confNew:      confidence vector associated with vetTnew.

% Initialization
N = length(vetT);
vetTnew = vetT;
vetSovrapNew = vetSovrap;
confNew = conf;


for i = 1:N
    if ~isnan(vetTtoAdd(i)) && isnan(vetT(i))
        vetTnew(i) = vetTtoAdd(i);
        confNew(i) = conftoAdd(i);
        vetSovrapNew(i) = 1;
    end
    if ~isnan(vetTtoAdd(i)) && ~isnan(vetT(i))
        confNew(i) = conf(i) + conftoAdd(i);
        vetTnew(i) = (conf(i)*vetT(i) + conftoAdd(i)*vetTtoAdd(i))/confNew(i);
        vetSovrapNew(i) = vetSovrap(i) + 1;
    end
end
    