function [Map1, Map2] = createMap(binImage, matTemp)
% Function that creates a map of values starting form the object silhouette
% in the thermogram.

% INPUT:  
% binImage: binary matrix with ones in correspondence of the silhouette.
% matTemp:  temperature matrix.
%
% OUTPUT: 
% Map1: map of contourns identifyed by consecutive integer number 
%       starting from the silhouette and propagating internally and 
%       externally.
% Map2: starting from Map1, a new number is assigned to each contourn, 
%       following a specific function.


% Map1 initialization
[Rv, Rh] = size(binImage);
Map1 = NaN(Rv,Rh);
for i = 1:Rv
    for j = 1:Rh
        if binImage(i,j) == 1
            Map1(i,j) = 1;
        end
    end
end


%-------------------------- Construction of Map1 -------------------------%
n_level = 500;  % Number of level of countorn propagation tried by the algo
for level = 2:n_level
    for i = 1:Rv
        for j = 1:Rh
            if ~isnan(Map1(i,j)) && Map1(i,j) == level - 1
                Map1 = expandPattern([i,j], level, Map1);
            end
        end
    end
end


%-------------------------- Construction of Map2 -------------------------%
Map2 = zeros(Rv,Rh);
for i = 1:Rv
    for j = 1:Rh
        if ~isnan(matTemp(i,j))
            Map2(i,j) = (10*exp(-10^(-3)*(Map1(i,j) - 1).^2))/10^3;
        else
            Map2(i,j) = (10*exp(-10^(-3)*(Map1(i,j) - 1).^2) - 11)/10^3;
        end
    end
end


figure
grayMap2 = mat2gray(Map2);
imshow(grayMap2)
colormap(gca, 'jet')
ticks = [0 0.25 0.5 0.75 1];
maxMap2 = max(max(Map2));
minMap2 = min(min(Map2));
dif = maxMap2 - minMap2;
c1 = colorbar('Ticks', ticks,'TickLabels',{string(round(10000*minMap2)), string(round(10000*(minMap2 + 0.25*dif))), string(round(10000*(minMap2 + 0.5*dif))), string(round(10000*(minMap2 + 0.75*dif))), string(round(10000*(maxMap2)))});
c1.Label.String = '10^{ 4} y';
set(gca,'fontsize',12);
set(gca,'FontWeight','bold');
set(gca,'LineWidth',1.5);
set(gca,'TickLength',[0.018, 0.018]);

end