function matTnew = erodeIm(matT)
% Function that erodes the contour of the object.

% INPUT:
% matT:     temperature matrix in which the background pixels are NaN.

% OUTPUT:
% matTnew:  matrix in which the object contourn is eroded (points near
%           contourn become NaN).

% Initialization
[Rv,Rh] = size(matT);
matTnew = NaN(Rv, Rh);

% Creation of a binary matrix from matT
matBin = zeros(Rv, Rh);
for i = 1:Rv
    for j = 1:Rh
        if ~isnan(matT(i,j))
            matBin(i,j) = 1;
        end
    end
end

% Erosion of the binary matrix created
seD = strel('diamond',4);  %%%%
matBin2 = imerode(matBin,seD);

% Reconversion of the binary matrix into the temperature matrix
for i = 1:Rv
    for j = 1:Rh
        if matBin2(i,j) == 1
            matTnew(i,j) = matT(i,j);
        end
    end
end


end

