% Example 2
% This example shows the integration of multiple thermograms on the same 
% point cloud. 17 thermograms are integrated.


close all

% Loading the point cloud 
ptCloud = pcread('examples\TARGET3D.ply');  
N = ptCloud.Count;

% Initialization
vetSovrap = zeros(N,1); % Vector with the number of overlapping temperatures in each point
vetT = NaN(N,1); % Vector of temperatures
conf = NaN(N,1); % Vector of confidence of each temperature
matTOT = [ptCloud.Location, vetT, conf, vetSovrap]; % Matrix in which all the information is stored  

% Setting the rng seed 
rng(4,'twister');

% Integrating 17 thermograms
for i = 1:17
    
    % Loading the file with the 2D-3D point correspondence
    % The first two column of the file are the coordinates of the 2D 
    % points, whereas the other 3 columns are the coordinate of the 3D 
    % points. This file was created by manually selecting a series of 
    % homologous points from the point cloud and the thermogram.
    CP = load(strcat('examples\','Pts2D3D_',int2str(i),'.txt'));
    Points_2D = CP(:,1:2);
    Points_3D = CP(:,3:5);
    
    % Loading the temperature matrix
    matTemp = xlsread(strcat('examples\','thermogram',int2str(i)));
    
    disp(strcat('Integrating thermogram',int2str(i)));
    
    % Integrating the temperature matrix with the point cloud
    [vetTtoAdd, Theta, conftoAdd, worldLocation, worldOrientation] = thermography3D(Points_2D, Points_3D, ptCloud, matTemp, 0, 0);
    
    % Updating the value of the temperature in every point if there is more
    % than one temperature value associated
    [vetTnew, vetSovrapNew, confNew] = combineVetT(matTOT(:,4), matTOT(:,5), vetTtoAdd, conftoAdd, matTOT(:,6));
    
    % Updating the total matrix in which all the information is stored
    matTOT = [ptCloud.Location, vetTnew, confNew, vetSovrapNew];
end

% Showing the results
show3DTcloud(matTOT(:,4),ptCloud, 'hot', [])
axis off
set(gcf,'color',[0 128/255 1])