function Ind = excludePoints(matPix, dist, Res, chi)
% Function that performs the first type of exclusion.

% INPUT:
% matPix:   N-by-2 matrix containing, for each cloud point, the indices of 
%           the corresponding pixel in the temperature matrix. 
% dist:     distance of each cloud point from the optical centre.     
% Res:      vector containing the temperature matrix resolution in the 
%           form: [vertical resolution, horizontal resolution].
% chi:      exclusion parameter.

% OUTPUT:
% Ind:      Indices to become NaN in the matrix matPix.


Rv = Res(1); % Vertical resolution
Rh = Res(2); % Horizontal resolution
N = size(matPix,1); % Number of cloud points

% Initialization
Ind = NaN(1,N);
matMin = inf*ones(Rv,Rh);
count = 1;

% Computing the minimum distance between each point associated to the same
% pixel
for i = 1:N
    if ~isnan(matPix(i,1)) && (dist(i) < matMin(matPix(i,1), matPix(i,2)))
        matMin(matPix(i,1),matPix(i,2)) = dist(i);
    end
end

% Finding the indices of the points to be excluded
for i = 1:N
    if ~isnan(matPix(i,1)) && (dist(i) > matMin(matPix(i,1), matPix(i,2)) + chi)
        Ind(count) = i;
        count = count + 1;
    end
end
