function maskX = fmaskX(matTemp)
% Function that creates a binary matrix with ones in correspondence of the
% contourn.

% INPUT:
% matTemp: thermogram in which the background pixel are NaN. 

% OUTPUT:
% maskX: it is a binary matrix with 1 in corresponce of the contourn and 0 
%        otherwise.


% Resolution
[Rv, Rh] = size(matTemp);

% Initialization
mask = ones(Rv,Rh);

% Converting the thermogram into a binary image in which the points
% belonging to the background are set to 0 whereas the points belonging to
% the object are set to one
for i = 1:Rv
    for j = 1:Rh
        if isnan(matTemp(i,j)) 
            mask(i,j) = 0;
        else
            mask(i,j) = 1;
        end
    end
end

% Dilate the image using a structuring element of type "square" 
SE = strel('square', 3);
mask_dil = imdilate(mask, SE);

% Tranform mask_dil into a binary image with 1 on the contourn and 0 
% otherwise
maskX = edge(mask_dil);

           