function maskY = fmaskY(AllProjPoints, Res)
% Function that constructs a binary image maskY in which each pixel has 
% value 1 if at least one 3D point is projected onto that pixel, 0
% otherwise.

% INPUT:
% AllProjPoints: projection on the image plane of all the 3D points of the 
%                point cloud.
% Res: resolution of the thermogram in the form (vertical res, horizontal
%      res).


Rv = Res(1); % Vertical resolution
Rh = Res(2); % Horizontal resolution

% Initialization
maskY = zeros(Rv,Rh); 
count = 0;

% Each projected point is associated to a pixel
pixelPoints = round([AllProjPoints(:,2), AllProjPoints(:,1)]);

% Each pixel that contains at least one projected 3D point becomes 1; its
% neighbours become one as well (for better results in the case of sparse 
% point clouds)
for i = 1:size(pixelPoints,1)
    if (pixelPoints(i,1) >= 1+1 && pixelPoints(i,1) <= Rv-1) && (pixelPoints(i,2) >= 1+1 && pixelPoints(i,2) <= Rh-1)
        maskY(pixelPoints(i,1),pixelPoints(i,2)) = 1;
        maskY(pixelPoints(i,1)+1,pixelPoints(i,2)) = 1;
        maskY(pixelPoints(i,1)-1,pixelPoints(i,2)) = 1;
        maskY(pixelPoints(i,1),pixelPoints(i,2)+1) = 1;
        maskY(pixelPoints(i,1),pixelPoints(i,2)-1) = 1;
        maskY(pixelPoints(i,1)+1,pixelPoints(i,2)+1) = 1;
        maskY(pixelPoints(i,1)-1,pixelPoints(i,2)+1) = 1;
        maskY(pixelPoints(i,1)+1,pixelPoints(i,2)-1) = 1;
        maskY(pixelPoints(i,1)-1,pixelPoints(i,2)-1) = 1;
        count = count + 1;
    end
end
