function [Score, maskY, maskZ] = objFunction(ext_par, pts3D, maskX2, K)
% Objective function that computes a certain score depending on where 
% the 3D points are reprojected.

% INPUT:
% ext_par:  vector containing the extrinsic parameters whose score is 
%           evaluated.
% pts3D:    3D points of the cloud.
% maskX2:   map of values generated starting from the object contourn 
% K:        intrinsic matrix.

% OUTPUT:
% Score:    result of the objective function.
% maskY:    binary image in which each the pixel has value 1 if at least 
%           one 3D point is projected onto that pixel, 0 otherwise.


% Euler angles
eul = ext_par(1:3);

% Translation vector
t = ext_par(4:6);

% Resolution
[Rv, Rh] = size(maskX2);

% Rotation matrix
R = eul2rotm(eul);

CameraMatrix = [R; t]*K;

% Projection of the 3D points onto the image plane
P2D_a = [pts3D ones(size(pts3D,1),1)]*CameraMatrix;
P2D_ok = bsxfun(@rdivide, P2D_a(:, 1:2),P2D_a(:, 3));


maskY = fmaskY(P2D_ok, [Rv,Rh]);

maskZ = maskX2.*maskY;

Score = -sum(maskZ(:));
